@@ -54,15 +54,23 @@ void on_command_picker_value_changed(HildonPickerButton * button, QueenBeecon *s
 
 }
 
+void on_logger_picker_value_changed(HildonPickerButton * button, QueenBeecon *self)
+{
+	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V2, "(%p) %s", self, G_STRFUNC);
+	QbwLoggerVerbosity verbosity = hildon_picker_button_get_active (HILDON_PICKER_BUTTON (button));
+	qbw_logger(QBW_LOGGER_SET_VERBOSITY, verbosity, NULL);
+}
+
 void testDriveBt_clicked_cb(HildonButton * button, QueenBeecon *self)
 {
+#define LINE_BUFFER_LENGTH 32768
 	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V2, "(%p) %s", self, G_STRFUNC);
 	int cmdSel;
 	FILE *fp = NULL;
 	gchar *line;//AP Big Big command output buffer//AP
 	size_t l;//AP
 	GtkTextIter start, end;
-	line = g_malloc0(4096);
+	line = g_malloc0(LINE_BUFFER_LENGTH);
 	gtk_text_buffer_get_bounds (self->priv->cmdTestDriveBuffer, &start, &end);
 	gchar *c = g_strdup(gtk_text_buffer_get_text (self->priv->cmdTestDriveBuffer,&start, &end, FALSE));
 	if (c[0] == '\0') {
@@ -76,15 +84,14 @@ void testDriveBt_clicked_cb(HildonButton * button, QueenBeecon *self)
 	fp = popen (instanceCmdSubst, "r");
 	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) ========> popen(%s) TEST DRIVE returned %p", self, instanceCmdSubst, fp);
 	g_free(instanceCmdSubst);
-
-	if ((l=fread (line, 1, sizeof line, fp))!=0) //to this "buffer-based" for multiline handling in widget //AP
-		line[l-1]='\000';//AP
+	l=fread (line, 1, LINE_BUFFER_LENGTH, fp);
+	line[LINE_BUFFER_LENGTH-1]='\000';//AP
+	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) fread(l=%d,line=%s)", self, l, line);
 	gint exitCode=pclose(fp);
-	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) ppclose(fp) returned 0x%08X", self, exitCode);
 
 	exitCode = (exitCode >> 8) & 0xff;
-	gchar *buff = g_strdup_printf("[Exit Code = %d]\n%s", (char)exitCode, line);//If command has output we issue a newline after Exit Code
-	gtk_text_buffer_set_text(self->priv->cmdOutputBuffer,buff,-1);
+	gchar *buff = g_strdup_printf("[Exit Code = %d Output Size = %d]\n%s", (char)exitCode, l, line);//If command has output we issue a newline after Exit Code
+	gtk_text_buffer_set_text(self->priv->cmdOutputBuffer,buff,strlen(line));
 	g_free(buff);
 	g_free(line);
 	g_free(c);
@@ -579,6 +586,7 @@ gboolean queen_beecon_advanced_dialog ( QueenBeecon *self, gint cmdSel )
 	gboolean reReadSettings = FALSE;
 	gboolean timeToGoBack = FALSE;
 	gchar *title = NULL;
+	gint i;
 
 	title = g_strconcat ("Advanced Settings and Tools (... Hic Sunt Leones!)", NULL);
 	self->priv->advancedDialog = gtk_dialog_new_with_buttons (title, NULL, 0, NULL);
@@ -606,8 +614,22 @@ gboolean queen_beecon_advanced_dialog ( QueenBeecon *self, gint cmdSel )
 
 	GtkWidget *testDriveBox = gtk_hbox_new (FALSE, 0);
 
+	GtkWidget *loggerSelector = hildon_touch_selector_new_text ();
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (loggerSelector), "Disable");
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (loggerSelector), "v0");
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (loggerSelector), "v1");
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (loggerSelector), "v2");
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (loggerSelector), "v3");
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (loggerSelector), "v4");
+
+	GtkWidget *loggerPicker = hildon_picker_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
+	hildon_button_set_title (HILDON_BUTTON (loggerPicker), "Log:");
+	hildon_button_set_alignment (HILDON_BUTTON (loggerPicker), 0, 0.5, 0, 0);
+	hildon_picker_button_set_selector (HILDON_PICKER_BUTTON (loggerPicker), HILDON_TOUCH_SELECTOR (loggerSelector));
+	hildon_picker_button_set_active (HILDON_PICKER_BUTTON (loggerPicker), qbw_logger(QBW_LOGGER_GET_VERBOSITY, QBW_LOGGER_VNULL, NULL));
+	gtk_box_pack_start (GTK_BOX (testDriveBox), loggerPicker, FALSE, FALSE, 0);
+
 	GtkWidget *commandPickerSelector = hildon_touch_selector_new_text ();
-	gint i;
 	for(i=0;i<self->priv->c_size;i++)
 	{
 		hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (commandPickerSelector), self->priv->c_titles[i]);
@@ -783,6 +805,7 @@ gboolean queen_beecon_advanced_dialog ( QueenBeecon *self, gint cmdSel )
 	self->priv->cmdTestDriveBuffer = hildon_text_view_get_buffer (HILDON_TEXT_VIEW (cmdTestDrive));
 	self->priv->cmdOutputBuffer = hildon_text_view_get_buffer (HILDON_TEXT_VIEW (cmdOutput));
 
+	g_signal_connect (G_OBJECT (loggerPicker), "value-changed",G_CALLBACK (on_logger_picker_value_changed), self);
 	g_signal_connect (G_OBJECT (self->priv->commandPicker), "value-changed",G_CALLBACK (on_command_picker_value_changed), self);
 
 	cmdSel = hildon_touch_selector_get_active (HILDON_TOUCH_SELECTOR (commandPickerSelector), 0);
