@@ -233,6 +233,7 @@ needInstanceSettings:
 		self->priv->cmdImgFilename = g_strdup(queen_beecon_g_key_file_get_string (keyFile, sourceGroup, "cmdImgFilename", "queen-beecon.png"));//No Image filename
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) self->priv->cmdImgFilename = %p", self, self->priv->cmdImgFilename);
 
+		self->priv->cmdImgAngle = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "cmdImgAngle", 0); //Horizontal, Left to Right
 		self->priv->cmdImgZoom = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "cmdImgZoom", 0);//0=100% 1=Fit to Widget
 		self->priv->cmdFgRGB = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "cmdFgRGB", 1);//1-White
 
@@ -261,6 +262,7 @@ needInstanceSettings:
 		self->priv->resImgFilename = g_strdup(queen_beecon_g_key_file_get_string (keyFile, sourceGroup, "resImgFilename", "queen-beecon-resimg.png"));//No Image filename
 		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) self->priv->resImgFilename = %p", self, self->priv->resImgFilename);
 
+		self->priv->resImgAngle = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "resImgAngle", 0); //Horizontal, Left to Right
 		self->priv->resImgZoom = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "resImgZoom", 0);//0=100% 1=Fit to Widget
 		self->priv->resFgRGB = queen_beecon_g_key_file_get_integer (keyFile, sourceGroup, "resFgRGB", 1);//1=White
 
@@ -418,6 +420,7 @@ void queen_beecon_write_settings (QueenBeecon *self, gboolean needInstanceSettin
 		g_key_file_set_string (keyFile, self->priv->widgetID, "instanceCmd", self->priv->instanceCmd);
 		g_key_file_set_string (keyFile, self->priv->widgetID, "rememberMe", self->priv->rememberMe);
 		g_key_file_set_string (keyFile, self->priv->widgetID, "cmdImgFilename", self->priv->cmdImgFilename);//AP3
+		g_key_file_set_integer (keyFile, self->priv->widgetID, "cmdImgAngle", self->priv->cmdImgAngle);//AP1
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "cmdImgZoom", self->priv->cmdImgZoom);//AP3
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "cmdFgRGB", self->priv->cmdFgRGB);//AP3
 		g_key_file_set_string (keyFile, self->priv->widgetID, "cmdExtFgRGB", self->priv->cmdExtFgRGB);//AP3
@@ -429,6 +432,7 @@ void queen_beecon_write_settings (QueenBeecon *self, gboolean needInstanceSettin
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "cmdFontName", self->priv->cmdFontName);//AP1
 		g_key_file_set_double (keyFile, self->priv->widgetID, "cmdFontSize", self->priv->cmdFontSize);//AP1
 		g_key_file_set_string (keyFile, self->priv->widgetID, "resImgFilename", self->priv->resImgFilename);//AP3
+		g_key_file_set_integer (keyFile, self->priv->widgetID, "resImgAngle", self->priv->resImgAngle);//AP1
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "resImgZoom", self->priv->resImgZoom);//AP3
 		g_key_file_set_integer (keyFile, self->priv->widgetID, "resFgRGB", self->priv->resFgRGB);//AP3
 		g_key_file_set_string (keyFile, self->priv->widgetID, "resExtFgRGB", self->priv->resExtFgRGB);//AP3
