@@ -139,6 +139,7 @@ gboolean queen_beecon_update_content (QueenBeecon *self, const gchar *impulse);
 void queen_beecon_update_content_layout (QueenBeecon *self);
 void queen_beecon_draw_canvas(GtkWidget *widget);
 gboolean queen_beecon_expose_event (GtkWidget *widget, GdkEventExpose *event);
+gboolean queen_beecon_button_release_exec (QueenBeecon *self);
 
 //Dialogs prototypes:
 gboolean queen_beecon_edit_add_dialog ( QueenBeecon *self, gboolean new, gint curr);
@@ -163,8 +164,6 @@ struct _QueenBeeconPrivate
 	GtkWidget 		*cmdResult_lb;
 	GtkWidget 		*cmdResult_img;
 
-	gboolean 		isPressed;
-
 	/* widget's instance identification str */
 	gchar 			*widgetID;
 
@@ -188,6 +187,13 @@ struct _QueenBeeconPrivate
 		gboolean 		hideCanvas;
 		gboolean 		updOnStartup;
 		gboolean 		updOnClick;
+		gboolean 		isPressed;
+		gboolean 		clicksCount;
+		guint 			clicksTimerID;
+		gint			clickX;
+		gint			clickY;
+		GtkWidget 		*clickWidget;
+
 		gboolean 		updOnDesktop;
 		guint 			updNeworkPolicy;
 		gboolean 		updOnSight;
@@ -232,14 +238,26 @@ struct _QueenBeeconPrivate
 		gchar			*rememberMe;
 
 		GtkWidget 		*tableLayout;
+#ifndef MONO_HOTSPOT
+		GtkWidget 		*hotSpot;
+		GtkWidget 		*hotSpotEvent;
+#else // MONO_HOTSPOT
+#ifndef OLD_HOTSPOT_INDEX
+		GtkWidget 		*hotSpots[9][3][3];
+		GtkWidget 		*hotSpotsEvents[9][3][3];
+		guint			subHotSpotIndex;
+#else // OLD_HOTSPOT_INDEX
 		GtkWidget 		*hotSpots[3][3];
 		GtkWidget 		*hotSpotsEvents[3][3];
+#endif // OLD_HOTSPOT_INDEX
+#endif // MONO_HOTSPOT
 		guint			hotSpotIndex;
 		GtkWidget 		*tableHotSpots;
 		GtkWidget 		*beeExecuting_img;
 		GdkPixbuf      	*beeExecuting_pixbuf[QBW_PROGRESS_ANIMATION_FRAMES_MAX];
 		guint			beeExecuting_imgidx;
 		gchar			*cmdImgFilename;
+		guint			cmdImgAngle;
 		guint 			cmdImgZoom;
 		guint 			cmdFgRGB;
 		gchar 			*cmdExtFgRGB;
@@ -252,6 +270,7 @@ struct _QueenBeeconPrivate
 		gdouble 		cmdFontSize;//AP1
 
 		gchar			*resImgFilename;
+		guint			resImgAngle;
 		guint 			resImgZoom;
 		guint 			resFgRGB;
 		gchar 			*resExtFgRGB;
@@ -410,6 +429,8 @@ struct _QueenBeeconPrivate
 		GtkWidget *LayoutCmdLabelW;
 		GtkWidget *cmdImgVisPosBoxW;
 		GtkWidget *titleImgEntryW;
+		GtkWidget *cmdImgAngleW;
+		GtkWidget *cmdImgAngleSelectorW;
 		GtkWidget *beecon_cmdImgZoomW;
 		GtkWidget *beecon_cmdImgZoomSelectorW;
 		GtkWidget *cmdImgVisibilityPositionW;
@@ -433,6 +454,8 @@ struct _QueenBeeconPrivate
 		GtkWidget *LayoutResLabelW;
 		GtkWidget *resImgVisPosBoxW;
 		GtkWidget *resultsImgEntryW;
+		GtkWidget *resImgAngleW;
+		GtkWidget *resImgAngleSelectorW;
 		GtkWidget *beecon_resImgZoomW;
 		GtkWidget *beecon_resImgZoomSelectorW;
 		GtkWidget *resImgVisibilityPositionW;
@@ -477,6 +500,10 @@ struct _QueenBeeconPrivate
 		GtkWidget *updOnDBUSMatchRuleW;
 		GtkWidget *updOnDBUSMatchRuleLabelW;
 
+		//Remember Me Value
+		GtkWidget *rememberMeLabelW;
+		GtkWidget *rememberMeW;
+
 		GtkWidget *updPolicyLabelW;
 		GtkWidget *updBoxW;
 		GtkWidget *checkBtStartupW;
